"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SMS = void 0;
const helper_1 = require("../../utils/helper");
const network_helper_1 = require("../../utils/network_helper");
class SMS {
    /**
     *
     * Construct SMS Service Manager
     *
     * @template {NCPAuthKeyType} NCPAuthKeyType - NCP API Authentication Key Pair
     * @param {string} accessKey Access Key ID
     * @param {string} secretKey Secret Key
     *
     * @template {SMSserviceAuthType} SMSserviceAuthType - NCP SMS Service Required Key Pair
     * @param {string} phone Registered Caller ID ( Phone Number )
     * @param {string} serviceId OPEN API serviceId
     *
     * @memberof SMS
     */
    constructor(ncpAuthKey, smsAuth) {
        this.smsAuth = smsAuth;
        this.baseUrl = network_helper_1.BaseURL.sens;
        this.client = new network_helper_1.NCPClient(ncpAuthKey, this.baseUrl);
    }
    /**
     *
     * Service - Send SMS message
     *
     * @template {SendSMSParamType} SendSMSParamType - NCP SMS Service Message
     * @param {string} to Recipient's phone number
     * @param {string} content Message content to send
     * @param {?string} countryCode Recipient's country code (default 82)
     *
     * @template {SendSMSReturnType} SendSMSReturnType - NCP SMS Service responses
     * @returns {boolean} isSuccess Check if request is successful
     * @returns {number} status Http status code from response
     * @returns {string} statusText Http status text from response
     * @returns {?jsonObject} data Data from response ( If request is successful )
     *
     * @memberof SMS
     */
    async sendSMS(smsParam) {
        // construct Api Request for sendSMS service.
        const apiRequest = new APISendSMS(this.client.ncpAuthKey, this.smsAuth, smsParam);
        try {
            const response = await this.client.request(apiRequest);
            console.log(response);
            if (response.status === 202) {
                return {
                    isSuccess: true,
                    status: response.status,
                    statusText: response.statusText,
                    header: response.headers,
                    data: response.data
                };
            }
            else {
                return {
                    isSuccess: false,
                    status: response.status,
                    statusText: response.statusText,
                };
            }
        }
        catch (error) {
            return {
                isSuccess: false,
                status: error.response.status || 500,
                statusText: error.response.statusText || 'Internal Server Error',
            };
        }
    }
}
exports.SMS = SMS;
class APISendSMS {
    constructor(ncpAuthKey, smsAuth, smsParam) {
        this.method = 'POST';
        const { accessKey, secretKey } = ncpAuthKey;
        const { phone, serviceId } = smsAuth;
        const { to, content, countryCode = '82' } = smsParam;
        this.path = `/sms/v2/services/${serviceId}/messages`;
        const { timestamp, signature } = helper_1.generateApiSignature({ method: this.method, url: this.path, ncpAuthKey });
        this.headers = {
            'Content-Type': 'application/json; charset=utf-8',
            'x-ncp-iam-access-key': accessKey,
            'x-ncp-apigw-timestamp': timestamp,
            'x-ncp-apigw-signature-v2': signature,
        };
        this.body = {
            'type': 'SMS',
            'contentType': 'COMM',
            'countryCode': countryCode,
            'from': phone,
            'content': content,
            'messages': [
                {
                    'to': to,
                },
            ],
        };
    }
}
